import React, { useState, useRef, useLayoutEffect, Fragment, createElement } from 'react';
import figlet from 'figlet';
import slant from 'figlet/importable-fonts/Slant.js';

var ASCII = function ASCII(_ref) {
  var _ref$text = _ref.text,
      text = _ref$text === void 0 ? 'Hello!' : _ref$text,
      _ref$rainbow = _ref.rainbow,
      rainbow = _ref$rainbow === void 0 ? true : _ref$rainbow,
      _ref$font = _ref.font,
      font = _ref$font === void 0 ? slant : _ref$font,
      _ref$fallback = _ref.fallback,
      fallback = _ref$fallback === void 0 ? 'pre' : _ref$fallback,
      id = _ref.id;

  var _useState = useState(text),
      ascii = _useState[0],
      setAscii = _useState[1];

  var _useState2 = useState(0),
      width = _useState2[0],
      setWidth = _useState2[1];

  var _useState3 = useState(16),
      baseFontSize = _useState3[0],
      setBaseFontSize = _useState3[1];

  var preWrap = useRef(null);
  var widthTest = useRef(null);
  var lines = ascii.split('\n').filter(function (line) {
    return line.trim().length > 0;
  }) || [' '];
  var measuredWidth = widthTest.current ? widthTest.current.offsetWidth : 100;
  var lineLength = lines[0] ? lines[0].length : 1;
  var measuredFontSize = 100;
  var targetFontSize = measuredFontSize * (width / lineLength) / measuredWidth;
  var fontSize = targetFontSize < baseFontSize ? targetFontSize : baseFontSize;
  useLayoutEffect(function () {
    figlet.parseFont('Slant', font);
    figlet.text(text, {
      font: 'Slant'
    }, function (_err, data) {
      return setAscii(data);
    });

    var getParentWidth = function getParentWidth() {
      if (preWrap.current) {
        setWidth(preWrap.current.offsetWidth);
        setBaseFontSize(parseFloat(window.getComputedStyle(preWrap.current).getPropertyValue('font-size')));
      }
    };

    if (preWrap.current) getParentWidth();
    window.addEventListener('resize', getParentWidth);
    return function () {
      return window.removeEventListener('resize', getParentWidth);
    };
  }, [preWrap.current, text]);
  var hasMounted = ascii !== text;

  var Rainbow = function Rainbow() {
    var lineColors = lines.map(function (_line, line) {
      return Array.from('rbg').map(function (_c, rbgi) {
        return getPhaseRBG(line, rbgi * Math.PI * 2 / 3);
      });
    });

    function getPhaseRBG(rbgi, phase) {
      return Math.floor(Math.sin(Math.PI / lines.length * 2 * rbgi + phase) * 127) + 128;
    }

    return React.createElement(Fragment, null, lines.map(function (line, i) {
      var _lineColors$i = lineColors[i],
          red = _lineColors$i[0],
          blue = _lineColors$i[1],
          green = _lineColors$i[2];
      return React.createElement("pre", {
        key: i,
        style: {
          color: "rgb(" + red + "," + green + "," + blue + ")"
        }
      }, line);
    }));
  };

  var measureStyle = {
    fontSize: measuredFontSize + "px",
    position: 'absolute',
    visibility: 'hidden'
  };
  var uniqueClass = "responsive-ascii" + (id ? "-" + id : '');
  return React.createElement("div", {
    ref: preWrap,
    className: uniqueClass,
    title: text,
    "aria-label": text
  }, hasMounted ? React.createElement(Fragment, null, React.createElement("style", null, "." + uniqueClass + " {width: 100%;} ." + uniqueClass + " pre {margin: 0; padding: 0; font-size: " + fontSize + "px;}"), rainbow ? React.createElement(Rainbow, null) : React.createElement("pre", null, ascii)) : createElement(fallback, null, [ascii]), React.createElement("pre", {
    ref: widthTest,
    style: measureStyle
  }, "\xA0"));
};

export default ASCII;
//# sourceMappingURL=index.modern.js.map
